==> helldivers-2-api-0.0.1.tar.gz: helldivers-2-api-0.0.1/README_PYPI.md <==
# Helldivers 2 Python API

A Python abstraction layer for the [unofficial Helldivers 2 API](https://helldiverstrainingmanual.com/api)

## Key Features

* Fully typed data model
  - Planets
  - Sectors
  - Factions
  - Events
  - Campaigns
  - Attacks
* Simple to use
  - Use your IDE's autocompletion to simply traverse the data model tree
* Easy Install
  - Only dependency is [requests](https://pypi.org/project/requests/)!

## How To Use

Simply install the PyPI package via pip.

Make sure to check out the [examples](https://git.jdrodenkirchen.de/drodenkirchen/helldivers-2-python-api/-/tree/main/examples).

### Minimal usage example

```python
from helldivers2_api.api_client import ApiClient

my_client = ApiClient()

war_status = my_client.get_war_status()

print(war_status.planet_attacks)

#  [
#    PlanetAttack(source_planet_id=125, target_planet_id=34), 
#    PlanetAttack(source_planet_id=168, target_planet_id=34),
#    ...
#  ]

planet_name = my_client.get_planet_by_id(34).name
print(planet_name)

#  Hellmire
```


## Credits

This software uses the following open source packages:

- [Python](https://www.python.org/)
- [requests](https://pypi.org/project/requests/)

## License

```
        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
                Version 2, December 2004

Copyright (C) 2024 David Rodenkirchen <davidr.develop@gmail.com>

Everyone is permitted to copy and distribute verbatim or modified
copies of this license document, and changing it is allowed as long
as the name is changed.

        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

0. You just DO WHAT THE FUCK YOU WANT TO.
```

==> helldivers-2-api-0.0.2.tar.gz: helldivers-2-api-0.0.2/README_PYPI.md <==
# Helldivers 2 Python API

A Python abstraction layer for the [unofficial Helldivers 2 API](https://helldiverstrainingmanual.com/api)

## Key Features

* Fully typed data model
  - Planets
  - Sectors
  - Factions
  - Events
  - Campaigns
  - Attacks
* Simple to use
  - Use your IDE's autocompletion to simply traverse the data model tree
* Easy Install
  - Only dependency is [requests](https://pypi.org/project/requests/)!

## How To Use

Simply install the PyPI package via pip.

Make sure to check out the [examples](https://git.jdrodenkirchen.de/drodenkirchen/helldivers-2-python-api/-/tree/main/examples).

### Minimal usage example

```python
from helldivers2_api.api_client import ApiClient
from helldivers2_api.planet_info_table import get_planet_by_id

my_client = ApiClient()

war_status = my_client.get_war_status()

print(war_status.planet_attacks)

#  [
#    PlanetAttack(source_planet_id=125, target_planet_id=34), 
#    PlanetAttack(source_planet_id=168, target_planet_id=34),
#    ...
#  ]

planet_name = get_planet_by_id(34).name
print(planet_name)

#  Hellmire
```


## Credits

This software uses the following open source packages:

- [Python](https://www.python.org/)
- [requests](https://pypi.org/project/requests/)

## License

```
        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
                Version 2, December 2004

Copyright (C) 2024 David Rodenkirchen <davidr.develop@gmail.com>

Everyone is permitted to copy and distribute verbatim or modified
copies of this license document, and changing it is allowed as long
as the name is changed.

        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

0. You just DO WHAT THE FUCK YOU WANT TO.
```
